@@ -114,30 +114,6 @@ POE::Component::Server::SimpleHTTP::Connection - Stores connection information f
 	# Print some stuff
 	print $connection->remote_port;
 
-=head1 CHANGES
-
-=head2 1.05
-
-	Added a new accessor for SSLfication
-	Removed some unnecessary variables
-
-=head2 1.04
-
-	Added the dead accessor
-
-=head2 1.03
-
-	Updated POD
-	Added local_ip + local_port accessors
-
-=head2 1.02
-
-	Got rid of funky CaPs in methods
-
-=head2 1.01
-
-	Initial Revision
-
 =head1 DESCRIPTION
 
 	This module simply holds some information from a SimpleHTTP connection.
@@ -172,7 +148,7 @@ Apocalypse E<lt>apocal@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004 by Apocalypse
+Copyright 2006 by Apocalypse
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
